%define soname 6

Name:           xtb
Version:        6.3.1
Release:        5%{?dist}
Summary:        Semiempirical Extended Tight-Binding Program Package
License:        LGPLv3+
URL:            https://github.com/grimme-lab/xtb/
Source0:        https://github.com/grimme-lab/xtb/archive/v%{version}/xtb-%{version}.tar.gz

# Fedora versioning
Patch0:         xtb-6.3.1-fedoraver.patch
# Increase test timeout; https://github.com/grimme-lab/xtb/pull/265
Patch1:         xtb-6.3.1-timeout.patch
# Use LAPACK for matmul; https://github.com/grimme-lab/xtb/pull/266
Patch2:         xtb-6.3.1-lapack.patch
# Fix crashes on several architectures; https://github.com/grimme-lab/xtb/pull/269
Patch3:         xtb-6.3.1-wsc.patch

BuildRequires:  gcc-gfortran
BuildRequires:  meson
BuildRequires:  ninja-build
BuildRequires:  openblas-devel
# To generate man pages
BuildRequires:  rubygem-asciidoctor
# The program queries $HOSTNAME at runtime and so fails to run in mock without this
BuildRequires:  hostname

%description
The xtb program package developed by the Grimme group in Bonn.

%package libs
Summary:   Data files and shared libraries for xtb
# The program queries $HOSTNAME at runtime and so fails to run in mock without this
Requires: hostname

%description libs
This package contains the data files and shared libraries for xtb.

%package devel
Summary:   Development headers for xtb
Requires:  %{name}-libs%{?_isa} = %{version}-%{release}

%description devel
This package contains development headers for xtb.

%prep
%setup -q
%patch0 -p1 -b .fedoraver
%patch1 -p1 -b .testtimeout
%patch2 -p1 -b .lapack
%patch3 -p1 -b .wsc

%build
%meson -Dla_backend=custom -Dcustom_libraries=openblaso -Dtest_timeout=2000
date=$(date)
# Create customized Fedora versioning
cat > %{_vpath_builddir}/xtb_version.fh <<EOF
character(len=*),parameter :: version = "%{version}-%{release}%{dist}"
character(len=*),parameter :: date = "$date"
character(len=*),parameter :: author = "Fedora project"
EOF
%meson_build

%install
%meson_install
# Remove static library
rm %{buildroot}%{_libdir}/libxtb.a

# Create profile files
mkdir -p %{buildroot}%{_sysconfdir}/profile.d
cat > %{buildroot}%{_sysconfdir}/profile.d/xtb.sh <<EOF
XTBPATH=%{_datadir}/xtb
export XTBPATH
EOF
cat > %{buildroot}%{_sysconfdir}/profile.d/xtb.csh <<EOF
setenv XTBPATH %{_datadir}/xtb
EOF

%check
%meson_test

%files
# LGPLv3+ license is stated at bottom of README.md
%doc README.md CONTRIBUTING.md
%{_bindir}/xtb

%files libs
%license COPYING COPYING.LESSER README.md
%{_sysconfdir}/profile.d/xtb.sh
%{_sysconfdir}/profile.d/xtb.csh
%{_datadir}/xtb/
%{_mandir}/man1/xtb.1*
%{_mandir}/man7/xcontrol.7*
%{_libdir}/libxtb.so.%{soname}*

%files devel
%{_includedir}/xtb.h
%{_libdir}/libxtb.so
%{_libdir}/pkgconfig/xtb.pc

%changelog
* Tue Jun 30 2020 Susi Lehtola <jussilehtola@fedoraproject.org> - 6.3.1-5
- Review fixes.

* Sun Jun 21 2020 Susi Lehtola <jussilehtola@fedoraproject.org> - 6.3.1-4
- Drop Python requirements since the python stuff is now in another project.

* Thu Jun 18 2020 Susi Lehtola <jussilehtola@fedoraproject.org> - 6.3.1-3
- Fix crashes on several architectures.

* Thu Jun 18 2020 Susi Lehtola <jussilehtola@fedoraproject.org> - 6.3.1-2
- Add dependency on rubygem-asciidoc to get man pages.
- Increase test timeouts to avoid build failures.
- Disable architectures that fail to work.
- Use external BLAS library for matmul.

* Wed Jun 17 2020 Susi Lehtola <jussilehtola@fedoraproject.org> - 6.3.1-1
- First release.
